@@ -1,7 +1,7 @@
 ### OPEN SOURCE LICENSE - GNU AFFERO PUBLIC LICENSE Version 3.0 #######
 #
 #    Net::FullAuto Demonstration GUI
-#    Copyright (C) 2000-2015  Brian M. Kelly
+#    Copyright (C) 2000-2016  Brian M. Kelly
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as
@@ -34,13 +34,12 @@ use Term::Menus;
    --------------------------------------------------------
 
    If you are new to FullAuto, and would like a better idea of what it
-   is and what it does, please explore the brief introduction before
-   running the demonstration. You can access the introduction by just
-   pressing [ENTER]
+   is and what it does, please explore this brief introduction. You can
+   access the introduction by just pressing [ENTER]
 
    Otherwise, use the DOWN ARROW [v] key to move the arrow to item 2
-   and press [ENTER] - or just type 2 and press [ENTER] to start the
-   demonstration.
+   and press [ENTER] - or just type 2 and press [ENTER] to exit this
+   dialogue.
 
 END
 
@@ -55,15 +54,15 @@ END
     | || ' \  _| '_/ _ \/ _` | || / _|  _| / _ \ ' \
    |___|_||_\__|_| \___/\__,_|\_,_\__|\__|_\___/_||_|
    --------------------------------------------------
-
    FullAuto is a breakthrough innovation in Network Process Automation.
    Any time a process involves more than one device, it is a "networked"
    process. Anyone who uses the Internet, engages in "network processing"
-   - otherwise known as SURFING!
-
-   The KEY <~[] to process **AUTOMATION**, is secure, persistent access
-   to the command-line environments of connected devices. The Internet
-   is in fact BILLIONS of connected devices.
+   - it's called ... SURFING! The key to rapid, inexpensive yet infinitely
+   powerful and scalable network process automation is a SECURE and
+    _  __ _  __  __ ___ __    ___
+   |_)|_ |_)(_ |(_   | |_ |\ | |
+   |  |__| \__)|__)  | |__| \| | connection to the command-line environments
+   of remote devices. The Internet is in fact BILLIONS of connected devices.
 
    Browsers however, do NOT have direct access to the command-line
    functionality of remote devices, nor are they supposed to.
@@ -175,7 +174,6 @@ END
    | |__)  ) |   | ____/ ___ |  _ (  | |_| | | | |  | |_| | |_| ( (_| | | | |
    |______/|_|   |_____)_____|_| \_)  \__)_| |_|_|   \___/|____/ \___ |_| |_|
                                                                 (_____|
-
    Current automation technologies do not typically use generic and readily
    available utilities designed for human interaction - like the command
    shell you are now using for this demonstration. Rather they rely on an
@@ -223,7 +221,6 @@ END
     \  /\  /| | | | |_| | /\/ /_ | |_  / /\/\ \ (_| | |_| ||  __/ |  \__ \
      \/  \/ |_| |_|\__, | \____/  \__| \/    \/\__,_|\__|\__\___|_|  |___/
                    |___/
-
    For the very first time, there is now an automation tool that works just
    like computer professionals do. The very same commands and work-flows
    that professionals use every day can now be introduced almost verbatim
@@ -248,7 +245,6 @@ END
    /  _  \ | | | (_| |  \  /\  /| | | | |_| | / /\  / (_) \ V  V /   \/
    \_/ \_/_| |_|\__,_|   \/  \/ |_| |_|\__, | \_\ \/ \___/ \_/\_/    ()
                                        |___/
-
    False assumptions. The "experts" thought a tool like FullAuto was not
    possible. The assumption was because output from a generic connection
    could have INFINITE variation (TRUE), that there was "no way" to create
@@ -273,13 +269,12 @@ END
     \ \/\/ /| _||   / _|    | |/ |/ / , _/ /_/ /    / (_-- /_/
      \_/\_/ |___|_|_\___|   |__/|__/_/|_|\____/_/|_/\____/(_)
 
-
    Not the first time in history this has happened. There is no technical
    reason that a tool like FullAuto could not have been created 30 years
    ago, but for the false belief that it wasn't possible. Experts will
    generally not spend their time trying to solve "impossible" problems.
    Not until Brian Kelly has anyone apparently thought any differently.
-   Brian conceived of FullAuto as early as 1998, and began active
+   Kelly conceived of FullAuto as early as 1998, and began active
    development in 2000. However, it would take 15 LONG years to make it
    a reality. The experts were wrong - but they weren't crazy. The
    problem was not trivial, and the solution is not either!
@@ -404,7 +399,7 @@ END
       },
       Item_2 => {
 
-         Text => "FullAuto Demonstration",
+         Text => "Exit this Dialogue",
 
       },
       Scroll => 1,
@@ -414,5 +409,4 @@ END
 
 
    my $demo_out=Menu(\%fullauto_demo);
-   print "DONE WITH DEMO\n";
    exit;
